Functions
Processes the given string, converting escape substrings into the proper characters.
Parse either nothing, or anything that can separate tokens, including spaces, comments, etc.
Processes the given string, converting escape substrings into the proper characters.
Parse either nothing, or anything that can separate tokens, including spaces, comments, etc.