Function modus_lib::sld::sld

source · []
pub fn sld(
    rules: &[Clause<IRTerm>],
    goal: &Vec<Literal<IRTerm>>,
    maxdepth: usize,
    store_full_tree: bool
) -> SLDResult
Returns a tree that contains both successful and failed paths, also, any resolution errors. To save on memory usage, can avoid storing the failed paths by passing false to store_full_tree.